.. HPE OneView Redfish Toolkit documentation master file, created by
   sphinx-quickstart on Wed Aug 10 09:44:28 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

HPE OneView Redfish Toolkit Reference
=======================================

The table of contents links to the API specification for each resource type in the HPE OneView Redfish Toolkit resource model.
These API specifications are intended to provide all the details needed to call the HP OneView Redfish Toolkit APIs.

* :ref:`modindex`
